# R script for the manuscript, Schäfer et.al. 2022
## Plot the differences in GR and levels of resistance;
## Author: Shuqing Xu (shuqing.xu@uni-mainz.de)
## Date: 2022-10-09

library("ggplot2")
library("MASS")
## variations of the resistance;
setwd("~/RawData/");

data.EX2<-read.table(file="MicrobiotaHerbivoryExperiments.txt",sep="\t",header=T);
data.EX2$Trait;
data.EX2<-data.EX2[!is.na(data.EX2$Value),]
data.EX2$Genotype<-as.factor(data.EX2$Genotype)
data.EX2.Res<-data.EX2[data.EX2$Trait=="Resistance",]; # Here, we used number of consumed fronds by the snails within 24 hours as the estimate of resistance.
data.EX2.Tol<-data.EX2[data.EX2$Trait=="Tolerance",]; # Here, we used growth rate after herbivory (8-13 days) as the estimate of tolerance.
data.EX2.GR<-data.EX2[data.EX2$Trait=="Growth",]; # Here, the growth rate was estimated by the first 1-7 days, with or without microbiota; 

# Q1: do different genotype differ in growth rate without microbiota inoculation?
## check whether the data is normal distributed
shapiro.test(data.EX2.GR$Value[data.EX2.GR$Treatment=="C"]); # less than 0.01

kruskal.test(data.EX2.GR$Value[data.EX2.GR$Treatment=="C"]~data.EX2.GR$Genotype[data.EX2.GR$Treatment=="C"]); # significantly different!
# plot differences in growth rate


# Q2: do different genotype differ in growth rate with  microbiota inoculation?
## check whether the data is normal distributed
shapiro.test(data.EX2.GR$Value[data.EX2.GR$Treatment=="M"]); # less than 0.01
kruskal.test(data.EX2.GR$Value[data.EX2.GR$Treatment=="M"]~data.EX2.GR$Genotype[data.EX2.GR$Treatment=="M"]); # significantly different!


# Q3: do different genotypes differ in resistance without microbiota inoculation?

# check whether data is normal distributed:
shapiro.test(data.EX2.Res$Value[data.EX2.Res$Treatment=="C"]); # larger than 0.01
# exam differenecs in resistance;
summary(lm(data.EX2.Res$Value[data.EX2.Res$Treatment=="C"]~data.EX2.Res$Genotype[data.EX2.Res$Treatment=="C"]));

# Q4: do different genotypes differ in tolerance without microbiota inoculation?

shapiro.test(data.EX2.Tol$Value[data.EX2.Tol$Treatment=="C"]);
# not normal distributed;
# use non-paramatric tests to see whether growth rate is difference among genotypes;
kruskal.test(data.EX2.Tol$Value[data.EX2.Tol$Treatment=="C"]~data.EX2.Tol$Genotype[data.EX2.Tol$Treatment=="C"]);

# Q5: do different genotypes differ in resistance with microbiota inoculation?
# check whether data is normal distributed:
shapiro.test(data.EX2.Res$Value[data.EX2.Res$Treatment=="M"]);
# exam differenecs in resistance;
summary(lm(data.EX2.Res$Value[data.EX2.Res$Treatment=="M"]~data.EX2.Res$Genotype[data.EX2.Res$Treatment=="M"]));

# Q6: do different genotypes differ in tolerance with microbiota inoculation?

shapiro.test(data.EX2.Tol$Value[data.EX2.Tol$Treatment=="M"]);
# not normal distributed;
# use non-paramatric tests to see whether growth rate is difference among genotypes;
summary(lm(data.EX2.Res$Value[data.EX2.Tol$Treatment=="M"]~data.EX2.Res$Genotype[data.EX2.Tol$Treatment=="M"]));


# make plot, sort data according to growth rate

se<-function(x) sqrt(var(x) / length(x));
PlotMeffect<-function(data.M=NULL,data.C=NULL, plot.order=c(30,14,9,1,5,2)){
  data.C.mean<-aggregate(data.C$Value, list(data.C$Genotype), mean);
  colnames(data.C.mean)<-c("Genotype","Value");
  data.net<-matrix(ncol=2,nrow=0)
  for(i in 1:nrow(data.M)){
    value.net<-(data.M$Value[i]-data.C.mean$Value[data.C.mean$Genotype==data.M$Genotype[i]])/data.C.mean$Value[data.C.mean$Genotype==data.M$Genotype[i]];
    data.net<-rbind(data.net,c(as.character(data.M$Genotype[i]),value.net));
  }
  data.net<-data.frame(data.net);
  colnames(data.net)<-c("Genotype","Value");
  data.net$Value<-as.numeric(as.character(data.net$Value))
  data.mean<-aggregate(data.net$Value, list(data.net$Genotype), mean);
  data.se<-aggregate(data.net$Value, list(data.net$Genotype), se);
  data.mean$SE<-data.se$x
  colnames(data.mean)<-c("Genotype","Value","SE");
  data.mean$Genotype<-factor(data.mean$Genotype,level=plot.order,ordered = T)
  summary(lm(data.net$Value~data.net$Genotype));
  p<-ggplot(data = data.mean, aes(x=Genotype, y=Value,fill=Genotype)) + 
    geom_bar(stat="identity",position=position_dodge())+
    geom_errorbar(aes(ymin=Value-SE, ymax=Value+SE),
                  width=0,                    # Width of the error bars
                  position=position_dodge(.9))+
    theme_minimal();
  p  
}



Data2BarPlot<-function(data=NULL,plot.order=c(30,14,9,1,5,2)){
  data.mean<-aggregate(data$Value, list(data$Genotype,data$Treatment), mean);
  data.se<-aggregate(data$Value, list(data$Genotype,data$Treatment), se);
  colnames(data.mean)<-c("Genotype","Treatment","Trait");
  data.mean$SE<-data.se$x
  data.mean$Genotype<-factor(data.mean$Genotype,level=plot.order,ordered = T)
  # data.mean$Genotype<-factor(data.mean$Genotype,level=plot.order,ordered = T)
  p<-ggplot(data = data.mean, aes(x=Genotype, y=Trait, fill=Genotype)) + 
    geom_bar(stat="identity",position=position_dodge())+
    geom_errorbar(aes(ymin=Trait-SE, ymax=Trait+SE),
                  width=0,                    # Width of the error bars
                  position=position_dodge(.9))+
    theme_minimal();
  p<-p+facet_grid(.~Treatment);
  
  p
}


# plot grow rate differences among genotypes without microbiota
data.EX2.sub<-data.EX2[data.EX2$Trait=="Growth" & data.EX2$Treatment=="C",]
p.growthrate.C<-Data2BarPlot(data.EX2.sub,plot.order = c(30,1,2,9,14,5));
ggsave(p.growthrate.C,file="GrowthRate.pdf");
# plot microbiota effects on growth rate;



# plot tolerance among genotypes
data.EX2.sub<-data.EX2[data.EX2$Trait=="Tolerance" & data.EX2$Treatment=="C",]
p.tolerance<-Data2BarPlot(data.EX2.sub,plot.order = c(30,1,2,9,14,5));
p.tolerance
ggsave(p.tolerance,file="Tolerance.pdf");


## plot resistance among genotypes;
p<-Data2BarPlot(data.EX2[data.EX2$Trait=="Resistance" & data.EX2$Treatment=="C",],plot.order =  c(30,1,2,9,14,5))
p
ggsave(p,file="Resistance.pdf");

## plot effects of M on resistance;

data.EX2.Res.M<-data.EX2.Res[data.EX2.Res$Treatment=="M",];
data.EX2.Res.C<-data.EX2.Res[data.EX2.Res$Treatment=="C",];
data.EX2.Tol.M<-data.EX2.Tol[data.EX2.Tol$Treatment=="M",];
data.EX2.Tol.C<-data.EX2.Tol[data.EX2.Tol$Treatment=="C",];
data.EX2.GR.M<-data.EX2.GR[data.EX2.GR$Treatment=="M",];
data.EX2.GR.C<-data.EX2.GR[data.EX2.GR$Treatment=="C",];

p.M_GR<-PlotMeffect(data.M=data.EX2.GR.M,data.C=data.EX2.GR.C, c(30,1,2,9,14,5));
ggsave(p.M_GR,file="Meffects_GR.pdf");

p.M_Resist<-PlotMeffect(data.M=data.EX2.Res.M,data.C=data.EX2.Res.C, c(30,1,2,9,14,5));
ggsave(p.M_Resist,file="Meffects_Resist.pdf");

p.M_Tol<-PlotMeffect(data.M<-data.EX2.Tol.M,data.C=data.EX2.Tol.C, c(30,1,2,9,14,5));
ggsave(p.M_Tol,file="Meffects_Tolerance.pdf");

# Statistic analysis on the interactions between microbiota and genotype
resist.model<-lm(Value~Genotype*Treatment,data=data.EX2.Res)
resist.model<-stepAIC(resist.model)
summary.aov(resist.model);
summary(resist.model)

Tol.model<-lm(Value~Genotype*Treatment,data=data.EX2.Tol)
Tol.model<-stepAIC(Tol.model)
summary.aov(Tol.model);
summary(resist.model)

GR.model<-lm(Value~Genotype*Treatment,data=data.EX2.GR)
GR.model<-stepAIC(GR.model)
summary.aov(GR.model);

sessionInfo()
